# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['rubric', 'rubric.files']

package_data = \
{'': ['*']}

entry_points = \
{'console_scripts': ['rubric = rubric.rubric:cli_entrypoint']}

setup_kwargs = {
    'name': 'rubric',
    'version': '0.3.9',
    'description': 'Rubric - Isomorphic Config for Your Python Project ⚙️',
    'long_description': '\n<div align="center">\n\n<h1>Rubric</h1>\n<strong>>> <i>Isomorphic Dependency & Configuration Management for Python Projects</i> <<</strong>\n\n&nbsp;\n\n</div>\n\n![img](https://user-images.githubusercontent.com/30027932/122619075-6a87b700-d0b1-11eb-9d6b-355446910cc1.png)\n\n\n## Preface\n\nRubric aims to lower the activation energy required to start a new Python project. Starting a new Python project usually entails—creating a new repo, cloning that to your local machine, creating and activating a virtual environment, manage the dependencies, adding linter configuration, and what not. Doing this over and over again in many different ways that are common in the Python ecosystem can be cumbersome. This means each of your projects will look slightly different in terms of what tools they\'re using to manage dependencies and how they\'re configured.\n\nAlso, if you\'re maintaining multiple repositories where they don\'t share a common structure on how they manage dependencies, configuration, linting, etc; it can go out of hand pretty quickly. Rubric can also help you make your existing projects conform to a single setup system.\n\nIt doesn\'t enforce any source code structure. Rather it just assumes that—you\'d want to use the following tools to lint and manage your code—and adds a bunch of sensible configuration files to your project\'s root folder:\n\n* [Black](https://github.com/psf/black) as the primary code formatter.\n* [Isort](https://github.com/PyCQA/isort) to sort the imports.\n* [Flake8](https://github.com/PyCQA/flake8) to ensure style guide conformance.\n* [Mypy](https://github.com/python/mypy) to check the type hints.\n* [Pip-tools](https://github.com/jazzband/pip-tools) to manage the dependencies.\n\nFollowing is a list of config files that Rubric is going to add to your target directory:\n\n```\nroot\n├── .flake8                # Config file for .flake8\n├── .gitignore             # Python specific .gitignore file\n├── makefile               # Makefile containing the commands to lint your code\n├── pyproject.toml         # Toml file to with the configs for mypy, black & isort\n├── README.md              # A readme boilerplate\n├── requirements-dev.in    # File to specify the top level dev requirements\n├── requirements-dev.txt   # File to specify the dev requirements\n├── requirements.in        # File to specify the top level app requirements\n└── requirements.txt       # File to specify the pinned app requirements\n```\n\nThe files will contain minimal but sensible default configurations for the respective tools. You\'re free to change them as you like.\n\n## Installation\n\n* Rubric requires Python 3.7 and up.\n\n* Make a virtual environment in your project\'s root directory.\n\n* Activate the environment and run:\n\n    ```\n    pip install rubric\n    ```\n\n## Usage\n\n* To inspect all the CLI options, run:\n\n    ```\n    rubric --help\n    ```\n\n    You should see the following output:\n\n    ```\n            Rubric - Isomorphic Dependency & Config Management for Python ⚙️\n\n    usage: rubric [-h] [-l] [-d] [-f  [...]] [-o  [...]] [-a  [...]] [-s  [...]] [-v]  [run]\n\n    positional arguments:\n      run                   Run rubric & initialize the project scaffold.\n\n    optional arguments:\n      -h, --help            Show this help message and exit.\n      -l, --list            List the config files that are about to be generated.\n      -d , --dirname        Target directory name.\n      -f  [ ...], --filename  [ ...]\n                            Target file names. Allowed values are: all, .flake8, .gitignore,\n                            README.md, makefile, pyproject.toml, requirements-dev.in,\n                            requirements-dev.txt, requirements.in, requirements.txt.\n      -o  [ ...], --overwrite  [ ...]\n                            Overwrite existing config files. Allowed values are the same as the\n                            values accepted by the \'-f/--file\' flag.\n      -a  [ ...], --append  [ ...]\n                            Append to existing config files. Allowed values are the same as the\n                            values accepted by the \'-f/--file\' flag.\n      -s  [ ...], --show  [ ...]\n                            Display the config file contents. Allowed values are the same as\n                            the values accepted by the \'-f/--file\' flag.\n      -v, --version         Display the version number.\n\n    ```\n\n* Display a list of config files that are going to be created:\n\n    ```\n    rubric --list\n    ```\n\n    ```\n            Rubric - Isomorphic Dependency & Config Management for Python ⚙️\n\n    Config files that are about to be generated:\n\n    => .flake8\n    => .gitignore\n    => README.md\n    => makefile\n    => pyproject.toml\n    => requirements-dev.in\n    => requirements-dev.txt\n    => requirements.in\n    => requirements.txt\n    ```\n\n* Take a peek into the content of any config file(s):\n    ```\n    rubric --show .flake8 requirements-dev.in\n    ```\n\n    This will print:\n\n    ```\n            Rubric - Isomorphic Dependency & Config Management for Python ⚙️\n\n\n    ================================= .flake8 =================================\n\n    [flake8]\n    extend-exclude =\n        .git,\n        __pycache__,\n        docs/source/conf.py,\n        old,\n        build,\n        dist,\n        .venv,\n        venv\n\n    extend-ignore = E203, E266, E501, W605\n\n    # Black\'s default line length.\n    max-line-length = 88\n\n    max-complexity = 18\n\n    # Specify the list of error codes you wish Flake8 to report.\n    select = B,C,E,F,W,T4,B9\n\n    # Parallelism\n    jobs = 4\n\n    =========================== requirements-dev.in ===========================\n\n    black\n    isort\n    flake8\n    mypy\n    pip-tools\n    ```\n\n\n* Initialize a project with the following command:\n\n    ```\n    rubric run\n    ```\n\n    This will run the tool in a non-destructive way—that means it won\'t overwrite any of the configuration files that you might have in the directory.\n\n* If you only want to create a selected list of config files, then run:\n\n    ```\n    rubric run -f requirements*\n    ```\n\n* If you want to overwrite any of the existing config files that you might have in the directory, then run:\n\n    ```\n    rubric run --overwrite filename1 filename2\n    ```\n\n* If you want to append the configs to an existing file, then run:\n\n    ```\n    rubric run --append filename1 filename2\n    ```\n\n* You can also point Rubric to a directory.\n\n    ```\n    rubric run --directory "some/custom/directory"\n    ```\n\n* If you want to check and update the configs across multiple repositories in a single sweep, use the following command:\n\n    ```\n    s="dir1 dir2 dir3"; echo $s | xargs -n 1 -P $(echo $s | wc -w) rubric run -d\n    ```\n\n    This command will spawn 3 processes to create the config files in `dir1`, `dir2`, and `dir3` in parallel.\n\n* You can run the entire linter suite with this command:\n\n    ```\n    make lint\n    ```\n\n<div align="center">\n<i> ✨ 🍰 ✨ </i>\n</div>\n',
    'author': 'rednafi',
    'author_email': 'redowan.nafi@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/rednafi/rubric',
    'packages': packages,
    'package_data': package_data,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
